# ezr.py

Explanation system for semi=supervised multi-objective optimization. 


## Install

Download ez.py.

Test:

    ./ez.py -h

## Run

Find some csv data where the first row names the columns 

- Uppercase names denote numerics (all others are symbolic)
- Names ending in "+" or "-" are goals to be minimized.
- Names ending in "!" show the klass column (there can only be one).

For examples, see the [/data](https://github.com/timm/ezr/tree/main/data) 
directory.
